ngff_zarr.multiscales - ngff-zarr
Description: Module Contents: Classes:,, Multiscales,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.multiscales`

## Module Contents

### Classes

`Multiscales` |

### API

class ngff_zarr.multiscales.Multiscales
  images: List[ngff_zarr.ngff_image.NgffImage]

    None

  metadata: ngff_zarr.zarr_metadata.Metadata

    None

  scale_factors: Optional[Sequence[Union[Dict[str, int], int]]]

    None

  method: Optional[ngff_zarr.methods.Methods]

    None

  chunks: Optional[Union[int, Tuple[int, ...], Tuple[Tuple[int, ...], ...], Mapping[Any, Union[None, int, Tuple[int, ...]]]]]

    None